<?php

/*******************************************************************************
Copyright (c) 2019-2024 Clear Admin Software Kft.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met: 

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer. 
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*******************************************************************************/

//tested with Wordpress 6.6.2 and WooCommerce 9.2.3

/******************************************************************************
HASZNÁLAT:
  A wordpress mappájában hozzon létre egy almappát
  (pl. 'clearadmin_kitalalhatatlanszo') és másolja bele ezt a php scriptet!
  Utána tesztelje az URL-t egy böngészővel.
  Ha rendben működik, az URL-t a Clear Admin Számlázó programban itt állítsa be:
    Fájl / Beállítások / Webáruház / Bizonylatok letöltése erről az URL-ről
*******************************************************************************/

$vat_number_meta_field = '_billing_vat_number';//cég esetén adószám ebben a meta mezőben van
$vat_percent = 27;//ÁFA

// Connect to WordPress
require_once(dirname(__FILE__) . '/../wp-load.php');

global $wpdb;

// Set character set
$wpdb->set_charset($wpdb->dbh, DB_CHARSET);

$last_orderhead_timestamp = @$_GET['last_orderhead_timestamp'];
if(!$last_orderhead_timestamp){
	$last_orderhead_timestamp = '2024-01-01 00:00:00';
}

$max_orders = intval(@$_GET['max_orders']);
if(!$max_orders) {
    $max_orders = 30;
}

$table_name = $wpdb->prefix . "posts";
$q = $wpdb->prepare(
    "SELECT * FROM $table_name 
    WHERE post_type LIKE 'shop_order%' 
    AND post_modified >= %s 
    ORDER BY post_modified 
    LIMIT %d",
    $last_orderhead_timestamp,
    $max_orders
);

$orders = $wpdb->get_results($q, ARRAY_A);

if($orders === false) {
    show_error("select order: " . $wpdb->last_error);
}

header('Content-Type: application/xml; charset=utf-8');
echo '<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>' . "\n";
echo "<!DOCTYPE ORDERS>\n";
echo "<ORDERS>\n";

foreach($orders as $order) {
    show_order($order);
}

echo "</ORDERS>";

function show_order($order) {
    global $wpdb, $vat_percent, $vat_number_meta_field;

    $order_id = $order['ID'];
    $wc_order = wc_get_order($order_id);

    if (!$wc_order) {
        return;
    }

    $user = array(
        'fname' => $wc_order->get_billing_first_name(),
        'lname' => $wc_order->get_billing_last_name(),
        'zip' => $wc_order->get_billing_postcode(),
        'address1' => $wc_order->get_billing_address_1(),
        'address2' => $wc_order->get_billing_address_2(),
        'company' => $wc_order->get_billing_company(),
        'city' => $wc_order->get_billing_city(),
        'paymentmethod_code' => $wc_order->get_payment_method(),
        'email' => $wc_order->get_billing_email()
    );
	$tax_no = '';
	$tax_no_type = '1';
	$is_company = strlen('' . $user['company']);
	if($is_company){
		$tax_no = $wc_order->get_meta($vat_number_meta_field);
		$tax_no_type = '3';
	}
	$partner_code =  $wc_order->get_user_id()+0 . '-' . $user['email'];

	$mail_company = $wc_order->get_shipping_company();
	$is_mail_company = strlen('' . $mail_company);
	$mail_name = $is_mail_company ? $mail_company : $wc_order->get_shipping_last_name() . ' ' . $wc_order->get_shipping_first_name();


    ?>
    <ORDER>
        <ORDERHEAD_CODE><?php echo esc_html($order_id); ?></ORDERHEAD_CODE>
        <ORDERHEAD_TIMESTAMP><?php echo esc_html($order['post_modified']); ?></ORDERHEAD_TIMESTAMP>
        <ORDERHEAD_PARTNER_CODE><?php echo esc_html($partner_code); ?></ORDERHEAD_PARTNER_CODE>
        <ORDERHEAD_PARTNER_NAME><?php echo esc_html($is_company ? $user['company'] : $user['fname'].' '.$user['lname']); ?></ORDERHEAD_PARTNER_NAME>
        <ORDERHEAD_PARTNER_ZIP><?php echo esc_html($user['zip']); ?></ORDERHEAD_PARTNER_ZIP>
        <ORDERHEAD_PARTNER_CITY><?php echo esc_html($user['city']); ?></ORDERHEAD_PARTNER_CITY>
        <ORDERHEAD_PARTNER_ADDRESS><?php echo esc_html($user['address1'].' '.$user['address2']); ?></ORDERHEAD_PARTNER_ADDRESS>

		<ORDERHEAD_PARTNER_MAIL_IS_SAME>0</ORDERHEAD_PARTNER_MAIL_IS_SAME>

		<ORDERHEAD_PARTNER_MAIL_NAME><?php echo esc_html($mail_name); ?></ORDERHEAD_PARTNER_MAIL_NAME>
		<ORDERHEAD_PARTNER_MAIL_ZIP><?php echo esc_html($wc_order->get_shipping_postcode()); ?></ORDERHEAD_PARTNER_MAIL_ZIP>
		<ORDERHEAD_PARTNER_MAIL_CITY><?php echo esc_html($wc_order->get_shipping_city()); ?></ORDERHEAD_PARTNER_MAIL_CITY>
		<ORDERHEAD_PARTNER_MAIL_ADDRESS><?php echo esc_html($wc_order->get_shipping_address_1() . ' ' . $wc_order->get_shipping_address_2()); ?></ORDERHEAD_PARTNER_MAIL_ADDRESS>

        <ORDERHEAD_PARTNER_TAX_NO><?php echo esc_html($tax_no); ?></ORDERHEAD_PARTNER_TAX_NO>
        <ORDERHEAD_PARTNER_TAX_NO_TYPE><?php echo $tax_no_type; ?></ORDERHEAD_PARTNER_TAX_NO_TYPE>

        <ORDERHEAD_PARTNER_CONTACT_EMAIL><?php echo esc_html($user['email']); ?></ORDERHEAD_PARTNER_CONTACT_EMAIL>
        <ORDERHEAD_PARTNER_CONTACT_NAME><?php echo esc_html($user['fname'].' '.$user['lname']); ?></ORDERHEAD_PARTNER_CONTACT_NAME>
        <ORDERHEAD_PAYMENTMETHOD_CODE><?php echo esc_html($user['paymentmethod_code']); ?></ORDERHEAD_PAYMENTMETHOD_CODE>
        <ORDERHEAD_DATE_SHIPPED><?php echo date("Y-m-d", strtotime($order['post_modified'])); ?></ORDERHEAD_DATE_SHIPPED>
        <ORDERHEAD_SUBJECT>Internetes vásárlás - megrendelés azonosítója: <?php echo intval($order_id); ?></ORDERHEAD_SUBJECT>
        <ORDERHEAD_VERIFIED>1</ORDERHEAD_VERIFIED>
        <?php show_orderitems($wc_order); ?>
    </ORDER>
    <?php
}

function show_orderitems($wc_order) {
    global $vat_percent;

    foreach ($wc_order->get_items() as $item_id => $item) {
        $product = $item->get_product();
        $item_total = $item->get_total();
        $item_qty = $item->get_quantity();

		$product_code = $item->get_product_id();
        $name = $item->get_name();
        $price = $item_total / $item_qty;
        $unit = 'db';
        $vat_code = $vat_percent;
		$part_no = $product ? $product->get_sku() : '';

        ?>
        <ORDERITEM>
            <ORDERITEM_PRODUCT_CODE><?php echo esc_html($product_code); ?></ORDERITEM_PRODUCT_CODE>
            <ORDERITEM_NAME><?php echo esc_html($name); ?></ORDERITEM_NAME>
            <ORDERITEM_PART_NO><?php echo esc_html($part_no); ?></ORDERITEM_PART_NO>
            <ORDERITEM_UNIT><?php echo esc_html($unit); ?></ORDERITEM_UNIT>
            <ORDERITEM_VAT_CODE><?php echo esc_html($vat_code); ?></ORDERITEM_VAT_CODE>
            <ORDERITEM_VAT_PERCENT><?php echo esc_html($vat_percent); ?></ORDERITEM_VAT_PERCENT>
            <ORDERITEM_VAT_NAME><?php echo esc_html($vat_percent . '%'); ?></ORDERITEM_VAT_NAME>
            <ORDERITEM_LIST_PRICE><?php echo number_format($price, 2, '.', ''); ?></ORDERITEM_LIST_PRICE>
            <ORDERITEM_QTY><?php echo esc_html($item_qty); ?></ORDERITEM_QTY>
        </ORDERITEM>
        <?php
    }

    // Handle shipping
    $shipping_total = $wc_order->get_shipping_total();
    if ($shipping_total > 0) {
        $shipping_methods = $wc_order->get_shipping_methods();
        $shipping_method = reset($shipping_methods);
        $shipping_name = $shipping_method ? $shipping_method->get_name() : 'Szállítási költség';
        ?>
        <ORDERITEM>
            <ORDERITEM_PRODUCT_CODE>SHIPPING</ORDERITEM_PRODUCT_CODE>
            <ORDERITEM_NAME><?php echo esc_html('Szállítási költség - ' . $shipping_name); ?></ORDERITEM_NAME>
            <ORDERITEM_UNIT></ORDERITEM_UNIT>
            <ORDERITEM_VAT_CODE><?php echo esc_html($vat_percent); ?></ORDERITEM_VAT_CODE>
            <ORDERITEM_VAT_PERCENT><?php echo esc_html($vat_percent); ?></ORDERITEM_VAT_PERCENT>
            <ORDERITEM_VAT_NAME><?php echo esc_html($vat_percent . '%'); ?></ORDERITEM_VAT_NAME>
            <ORDERITEM_LIST_PRICE><?php echo number_format($shipping_total, 2, '.', ''); ?></ORDERITEM_LIST_PRICE>
            <ORDERITEM_QTY>1</ORDERITEM_QTY>
        </ORDERITEM>
        <?php
    }

    // Handle fees (e.g., COD fee)
    foreach ($wc_order->get_fees() as $fee_id => $fee) {
        ?>
        <ORDERITEM>
            <ORDERITEM_CODE><?php echo esc_html('fee_' . $fee_id . '_' . $wc_order->get_id()); ?></ORDERITEM_CODE>
            <ORDERITEM_PRODUCT_CODE>FEE</ORDERITEM_PRODUCT_CODE>
            <ORDERITEM_NAME><?php echo esc_html($fee->get_name()); ?></ORDERITEM_NAME>
            <ORDERITEM_UNIT></ORDERITEM_UNIT>
            <ORDERITEM_VAT_CODE><?php echo esc_html($vat_percent); ?></ORDERITEM_VAT_CODE>
            <ORDERITEM_VAT_PERCENT><?php echo esc_html($vat_percent); ?></ORDERITEM_VAT_PERCENT>
            <ORDERITEM_VAT_NAME><?php echo esc_html($vat_percent . '%'); ?></ORDERITEM_VAT_NAME>
            <ORDERITEM_LIST_PRICE><?php echo number_format($fee->get_total(), 2, '.', ''); ?></ORDERITEM_LIST_PRICE>
            <ORDERITEM_QTY>1</ORDERITEM_QTY>
        </ORDERITEM>
        <?php
    }
}

function show_error($error_str) {
    echo esc_html($error_str);
    die();
}
